# Default environment collector

-----

This adds the `default` environment with [type](../../config/environment/overview.md#type) set to [virtual](../environment/virtual.md) and will always be applied.

## Configuration

The environment plugin name is `default`.

=== ":octicons-file-code-16: pyproject.toml"

    ```toml
    [tool.hatch.env.collectors.default]
    ```

=== ":octicons-file-code-16: hatch.toml"

    ```toml
    [env.collectors.default]
    ```

## Options

There are no options available currently.
